@@ -139,6 +139,10 @@ class fMMS_SenderUI(hildon.Program):
 		
 		self.window.add(align)
 		self.window.show_all()
+		
+		self.menu = self.cont.create_menu(self.window)
+		self.window.set_app_menu(self.menu)
+		
 		self.add_window(self.window)
 		
 		# so appearently throwing an exception here
@@ -336,10 +340,14 @@ class fMMS_SenderUI(hildon.Program):
 			#raise
 		except socket.error, exc:
 			log.exception("sender: %s %s", type(exc), exc)
-			code = str(exc.args[0])
-			text = str(exc.args[1])
+			try:
+				code = str(exc.args[0])
+				text = str(exc.args[1])
+			except:
+				code = exc
+				text = ""
 			note = osso.SystemNote(self.osso_c)
-			errmsg = code + " " + text
+			errmsg = "%s %s" % (code, text)
 			note.system_note_dialog("Sending failed:\nError: " + errmsg + " \nPlease make sure your APN settings are correct" , 'notice')
 			#raise
 		except Exception, exc:
